# nyno-client

Python client for Nyno (https://nyno.dev) server.

## Installation
```bash
pip install nyno-client


## Usage
from nyno_client import NynoClient

client = NynoClient(credentials="change_me")
